use fish::builtins::fish_indent;

fn main() {
    fish_indent::main();
}
